@@ -249,6 +249,10 @@ printContentBlock (Messages.ContentBlock_Code_Execution_Tool_Result{ Messages.to
   where
     unless False action = action
     unless True _ = pure ()
+printContentBlock (Messages.ContentBlock_Thinking{}) =
+    Text.IO.putStrLn "  [Thinking]"
+printContentBlock (Messages.ContentBlock_Redacted_Thinking{}) =
+    Text.IO.putStrLn "  [Redacted thinking]"
 printContentBlock (Messages.ContentBlock_Unknown{ Messages.type_ = t }) =
     Text.IO.putStrLn $ "  [Unknown] " <> t
 
